@@ -1,6 +1,10 @@
-from typing import Optional, Dict
+from typing import Dict, Optional
+import os
+from rich.console import Console
 
-from ciphey.iface import registry, Checker, Config, ParamSpec
+console = Console()
+
+from ciphey.iface import Checker, Config, ParamSpec, registry
 
 
 @registry.register
@@ -11,10 +15,11 @@ class HumanChecker(Checker[str]):
 
     def check(self, text: str) -> Optional[str]:
         with self._config().pause_spinner_handle():
-            response = input(f'Result {text.__repr__()} (y/N): ').lower()
+            response = console.input(f"Result [blue bold]{text.__repr__()}[/blue bold] ([green]y[/green]/[red]N[/red]): ")
         if response == "y":
+            self.clear_terminal()
             return ""
-        elif response == "n" or response == "":
+        elif response in ("n", ""):
             return None
         else:
             return self.check(text)
@@ -24,3 +29,7 @@ class HumanChecker(Checker[str]):
 
     def __init__(self, config: Config):
         super().__init__(config)
+
+    def clear_terminal(self):
+        # https://stackoverflow.com/a/2084628
+        os.system('cls' if os.name == 'nt' else 'clear')
